@@ -17,7 +17,8 @@ sub content {
 sub insert {
     my $self = shift;
     my $ast = shift;
-    $self->{output} .= $ast->{output} || '';
+    no warnings 'uninitialized';
+    $self->{output} .= $ast->{output};
 }
 
 1;
